@@ -16,11 +16,9 @@
 #    under the License.
 """OpenStack Client interface. Handles the REST calls and responses."""
 
-from __future__ import print_function
-
 import glob
 import hashlib
-import imp
+import importlib.util
 import itertools
 import logging
 import os
@@ -35,7 +33,6 @@ from keystoneauth1.identity import base
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import strutils
-osprofiler_web = importutils.try_import("osprofiler.web")  # noqa
 import requests
 from six.moves import urllib
 import six.moves.urllib.parse as urlparse
@@ -55,6 +52,12 @@ try:
 except ImportError:
     import simplejson as json
 
+try:
+    osprofiler_web = importutils.try_import("osprofiler.web")
+except Exception:
+    pass
+
+
 _VALID_VERSIONS = ['v2', 'v3']
 V3_SERVICE_TYPE = 'volumev3'
 V2_SERVICE_TYPE = 'volumev2'
@@ -266,6 +269,12 @@ class SessionClient(adapter.LegacyJsonAdapter):
     def get_with_base_url(self, url, **kwargs):
         return self._cs_request_base_url(url, 'GET', **kwargs)
 
+    def create_update_with_base_url(self, url, **kwargs):
+        return self._cs_request_base_url(url, 'PUT', **kwargs)
+
+    def delete_with_base_url(self, url, **kwargs):
+        return self._cs_request_base_url(url, 'DELETE', **kwargs)
+
 
 class HTTPClient(object):
 
@@ -277,7 +286,7 @@ class HTTPClient(object):
                  proxy_tenant_id=None, proxy_token=None, region_name=None,
                  endpoint_type='publicURL', service_type=None,
                  service_name=None, volume_service_name=None,
-                 bypass_url=None, retries=None,
+                 os_endpoint=None, retries=None,
                  http_log_debug=False, cacert=None,
                  auth_system='keystone', auth_plugin=None, api_version=None,
                  logger=None, user_domain_name='Default',
@@ -304,11 +313,12 @@ class HTTPClient(object):
         self.service_type = service_type
         self.service_name = service_name
         self.volume_service_name = volume_service_name
-        self.bypass_url = bypass_url.rstrip('/') if bypass_url else bypass_url
+        self.os_endpoint = os_endpoint.rstrip('/') \
+            if os_endpoint else os_endpoint
         self.retries = int(retries or 0)
         self.http_log_debug = http_log_debug
 
-        self.management_url = self.bypass_url or None
+        self.management_url = self.os_endpoint or None
         self.auth_token = None
         self.proxy_token = proxy_token
         self.proxy_tenant_id = proxy_tenant_id
@@ -484,10 +494,9 @@ class HTTPClient(object):
         try:
             version = get_volume_api_from_url(self.management_url)
         except exceptions.UnsupportedVersion as e:
-            if self.management_url == self.bypass_url:
-                msg = (_("Invalid url was specified in --os-endpoint or "
-                         "environment variable CINDERCLIENT_BYPASS_URL.\n"
-                         "%s") % six.text_type(e))
+            if self.management_url == self.os_endpoint:
+                msg = (_("Invalid url was specified in --os-endpoint %s")
+                       % six.text_type(e))
             else:
                 msg = (_("Service catalog returned invalid url.\n"
                          "%s") % six.text_type(e))
@@ -589,8 +598,8 @@ class HTTPClient(object):
             # existing token? If so, our actual endpoints may
             # be different than that of the admin token.
             if self.proxy_token:
-                if self.bypass_url:
-                    self.set_management_url(self.bypass_url)
+                if self.os_endpoint:
+                    self.set_management_url(self.os_endpoint)
                 else:
                     self._fetch_endpoints_from_auth(admin_url)
                 # Since keystone no longer returns the user token
@@ -609,8 +618,8 @@ class HTTPClient(object):
                     auth_url = auth_url + '/v2.0'
                 self._v2_or_v3_auth(auth_url)
 
-        if self.bypass_url:
-            self.set_management_url(self.bypass_url)
+        if self.os_endpoint:
+            self.set_management_url(self.os_endpoint)
         elif not self.management_url:
             raise exceptions.Unauthorized('Cinder Client')
 
@@ -690,7 +699,7 @@ def _construct_http_client(username=None, password=None, project_id=None,
                            region_name=None, endpoint_type='publicURL',
                            service_type='volume',
                            service_name=None, volume_service_name=None,
-                           bypass_url=None, retries=None,
+                           os_endpoint=None, retries=None,
                            http_log_debug=False,
                            auth_system='keystone', auth_plugin=None,
                            cacert=None, tenant_id=None,
@@ -701,6 +710,8 @@ def _construct_http_client(username=None, password=None, project_id=None,
     if session:
         kwargs.setdefault('user_agent', 'python-cinderclient')
         kwargs.setdefault('interface', endpoint_type)
+        kwargs.setdefault('endpoint_override', os_endpoint)
+
         return SessionClient(session=session,
                              auth=auth,
                              service_type=service_type,
@@ -727,7 +738,7 @@ def _construct_http_client(username=None, password=None, project_id=None,
                           service_type=service_type,
                           service_name=service_name,
                           volume_service_name=volume_service_name,
-                          bypass_url=bypass_url,
+                          os_endpoint=os_endpoint,
                           retries=retries,
                           http_log_debug=http_log_debug,
                           cacert=cacert,
@@ -788,6 +799,15 @@ def _discover_via_python_path():
             yield name, module
 
 
+def load_module(name, path):
+    module_spec = importlib.util.spec_from_file_location(
+        name, path
+    )
+    module = importlib.util.module_from_spec(module_spec)
+    module_spec.loader.exec_module(module)
+    return module
+
+
 def _discover_via_contrib_path(version):
     module_path = os.path.dirname(os.path.abspath(__file__))
     version_str = "v%s" % version.replace('.', '_')
@@ -800,7 +820,7 @@ def _discover_via_contrib_path(version):
         if name == "__init__":
             continue
 
-        module = imp.load_source(name, ext_path)
+        module = load_module(name, ext_path)
         yield name, module
 
 
