@@ -30,6 +30,18 @@ fake_attachment = {'attachment': {
     'instance': 'e84fda45-4de4-4ce4-8f39-fc9d3b0aa05e',
     'volume_id': '557ad76c-ce54-40a3-9e91-c40d21665cc3', }}
 
+fake_attachment_list = {'attachments': [
+    {'instance': 'instance_1',
+     'name': 'attachment-1',
+     'volume_id': 'fake_volume_1',
+     'status': 'reserved',
+     'id': 'attachmentid_1'},
+    {'instance': 'instance_2',
+     'name': 'attachment-2',
+     'volume_id': 'fake_volume_2',
+     'status': 'reserverd',
+     'id': 'attachmentid_2'}]}
+
 fake_connection_info = {
     'auth_password': 'i6h9E5HQqSkcGX3H',
     'attachment_id': 'a232e9ae',
@@ -289,15 +301,7 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
         return (200, {}, fake_attachment)
 
     def get_attachments(self, **kw):
-        return (200, {}, {
-            'attachments': [{'instance': 1,
-                             'name': 'attachment-1',
-                             'volume_id': 'fake_volume_1',
-                             'status': 'reserved'},
-                            {'instance': 2,
-                             'name': 'attachment-2',
-                             'volume_id': 'fake_volume_2',
-                             'status': 'reserverd'}]})
+        return (200, {}, fake_attachment_list)
 
     def post_attachments_a232e9ae_action(self, **kw):  # noqa: E501
         attached_fake = fake_attachment
@@ -671,19 +675,7 @@ class FakeHTTPClient(fake_v2.FakeHTTPClient):
 
 
 def fake_request_get():
-    versions = {'versions': [{'id': 'v1.0',
-                              'links': [{'href': 'http://docs.openstack.org/',
-                                         'rel': 'describedby',
-                                         'type': 'text/html'},
-                                        {'href': 'http://192.168.122.197/v1/',
-                                         'rel': 'self'}],
-                              'media-types': [{'base': 'application/json',
-                                               'type': 'application/'}],
-                              'min_version': '',
-                              'status': 'DEPRECATED',
-                              'updated': '2016-05-02T20:25:19Z',
-                              'version': ''},
-                             {'id': 'v2.0',
+    versions = {'versions': [{'id': 'v2.0',
                               'links': [{'href': 'http://docs.openstack.org/',
                                          'rel': 'describedby',
                                          'type': 'text/html'},
@@ -692,7 +684,7 @@ def fake_request_get():
                               'media-types': [{'base': 'application/json',
                                                'type': 'application/'}],
                               'min_version': '',
-                              'status': 'SUPPORTED',
+                              'status': 'DEPRECATED',
                               'updated': '2014-06-28T12:20:21Z',
                               'version': ''},
                              {'id': 'v3.0',
@@ -711,19 +703,7 @@ def fake_request_get():
 
 
 def fake_request_get_no_v3():
-    versions = {'versions': [{'id': 'v1.0',
-                              'links': [{'href': 'http://docs.openstack.org/',
-                                         'rel': 'describedby',
-                                         'type': 'text/html'},
-                                        {'href': 'http://192.168.122.197/v1/',
-                                         'rel': 'self'}],
-                              'media-types': [{'base': 'application/json',
-                                               'type': 'application/'}],
-                              'min_version': '',
-                              'status': 'DEPRECATED',
-                              'updated': '2016-05-02T20:25:19Z',
-                              'version': ''},
-                             {'id': 'v2.0',
+    versions = {'versions': [{'id': 'v2.0',
                               'links': [{'href': 'http://docs.openstack.org/',
                                          'rel': 'describedby',
                                          'type': 'text/html'},
@@ -732,7 +712,7 @@ def fake_request_get_no_v3():
                               'media-types': [{'base': 'application/json',
                                                'type': 'application/'}],
                               'min_version': '',
-                              'status': 'SUPPORTED',
+                              'status': 'DEPRECATED',
                               'updated': '2014-06-28T12:20:21Z',
                               'version': ''}]}
     return versions
